==> kubernetes-model-1.0.32-sources.jar: annotations/io/fabric8/kubernetes/api/model/CapabilitiesBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.ArrayList;
import java.util.Map;
import java.util.HashMap;
import java.util.List;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Builder;

public class CapabilitiesBuilder extends CapabilitiesFluentImpl<CapabilitiesBuilder> implements VisitableBuilder<Capabilities,CapabilitiesBuilder>{

     CapabilitiesFluent<?> fluent;
public CapabilitiesBuilder(){
    this(new Capabilities());
}
public CapabilitiesBuilder( CapabilitiesFluent<?> fluent ){
    this(fluent, new Capabilities());
}
public CapabilitiesBuilder( CapabilitiesFluent<?> fluent , Capabilities instance ){
    this.fluent = fluent; fluent.withAdd(instance.getAdd()); fluent.withDrop(instance.getDrop()); 
}
public CapabilitiesBuilder( Capabilities instance ){
    this.fluent = this; this.withAdd(instance.getAdd()); this.withDrop(instance.getDrop()); 
}

public EditableCapabilities build(){
    EditableCapabilities buildable = new EditableCapabilities(fluent.getAdd(),fluent.getDrop());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
CapabilitiesBuilder that = (CapabilitiesBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.46-sources.jar: annotations/io/fabric8/kubernetes/api/model/CapabilitiesBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.ArrayList;
import java.util.RandomAccess;
import java.util.Map;
import java.util.Map;
import java.util.List;
import java.util.List;
import java.util.AbstractCollection;
import java.util.AbstractList;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Collection;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class CapabilitiesBuilder extends CapabilitiesFluentImpl<CapabilitiesBuilder> implements VisitableBuilder<Capabilities,CapabilitiesBuilder>{

     CapabilitiesFluent<?> fluent;
public CapabilitiesBuilder(){
    this(new Capabilities());
}
public CapabilitiesBuilder( CapabilitiesFluent<?> fluent ){
    this(fluent, new Capabilities());
}
public CapabilitiesBuilder( CapabilitiesFluent<?> fluent , Capabilities instance ){
    this.fluent = fluent; fluent.withAdd(instance.getAdd()); fluent.withDrop(instance.getDrop()); 
}
public CapabilitiesBuilder( Capabilities instance ){
    this.fluent = this; this.withAdd(instance.getAdd()); this.withDrop(instance.getDrop()); 
}

public EditableCapabilities build(){
    EditableCapabilities buildable = new EditableCapabilities(fluent.getAdd(),fluent.getDrop());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
CapabilitiesBuilder that = (CapabilitiesBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
